Crate singe_cusparse_sys

Crate singe_cusparse_sys 

Raw FFI bindings for cuSPARSE.

Prefer the safe singe-cusparse crate unless direct NVIDIA ABI access is required.

Structs

CUstream_st
_IO_FILE
_IO_codecvt
_IO_marker
_IO_wide_data
__BindgenBitfieldUnit
bsric02Info
bsrilu02Info
bsrsm2Info
bsrsv2Info
csric02Info
csrilu02Info
csru2csrInfo
cusparseColorInfo
cusparseContext
cusparseDnMatDescr
cusparseDnVecDescr
cusparseMatDescr
cusparseSpGEMMDescr
cusparseSpMMOpPlan
cusparseSpMatDescr
cusparseSpSMDescr
cusparseSpSVDescr
cusparseSpVecDescr
double2
float2
pruneInfo

Enums

cusparseAction_t
This type indicates whether the operation is performed only on indices or on data and indices.
cusparseColorAlg_t
cusparseCsr2CscAlg_t
cusparseDenseToSparseAlg_t
cusparseDiagType_t
This type indicates if the matrix diagonal entries are unity. The diagonal elements are always assumed to be present, but if cusparseDiagType_t::CUSPARSE_DIAG_TYPE_UNIT is passed to an API routine, then the routine assumes that all diagonal entries are unity and will not read or modify those entries. Note that in this case the routine assumes the diagonal entries are equal to one, regardless of what those entries are actually set to in memory.
cusparseDirection_t
This type indicates whether the elements of a dense matrix should be parsed by rows or by columns (assuming column-major storage in memory of the dense matrix) in function cusparse[S|D|C|Z]nnz. Besides storage format of blocks in BSR format is also controlled by this type.
cusparseFillMode_t
This type indicates if the lower or upper part of a matrix is stored in sparse storage.
cusparseFormat_t
This type indicates the format of the sparse matrix. See cuSPARSE Storage Formats for their description.
cusparseIndexBase_t
This type indicates if the base of the matrix indices is zero or one.
cusparseIndexType_t
This type indicates the index type for representing the sparse matrix indices.
cusparseMatrixType_t
This type indicates the type of matrix stored in sparse storage. Notice that for symmetric, Hermitian and triangular matrices only their lower or upper part is assumed to be stored.
cusparseOperation_t
This type indicates which operations is applied to the related input (e.g. sparse matrix, or vector).
cusparseOrder_t
This type indicates the memory layout of a dense matrix.
cusparsePointerMode_t
This type indicates whether the scalar values are passed by reference on the host or device. It is important to point out that if several scalar values are passed by reference in the function call, all of them will conform to the same single pointer mode. The pointer mode can be set and retrieved using cusparseSetPointerMode and cusparseGetPointerMode routines, respectively.
cusparseSDDMMAlg_t
cusparseSolvePolicy_tDeprecated
This type indicates whether level information is generated and used in csrsv2, csric02, csrilu02, bsrsv2, bsric02 and bsrilu02.
cusparseSpGEMMAlg_t
cusparseSpMMAlg_t
cusparseSpMMOpAlg_t
cusparseSpMVAlg_t
cusparseSpMatAttribute_t
cusparseSpSMAlg_t
cusparseSpSMUpdate_t
cusparseSpSVAlg_t
cusparseSpSVUpdate_t
cusparseSparseToDenseAlg_t
cusparseStatus_t
This data type represents the status returned by the library functions and it can have the following values.

Constants

CUSPARSE_VERSION
CUSPARSE_VER_BUILD
CUSPARSE_VER_MAJOR
CUSPARSE_VER_MINOR
CUSPARSE_VER_PATCH

Functions

cusparseAxpbyDeprecated
The function computes the sum of a sparse vector vecX and a dense vector vecY.
cusparseBlockedEllGet
This function returns the fields of the sparse matrix descriptor spMatDescr stored in Blocked-Ellpack (ELL) format.
cusparseBsrSetStridedBatch
This function sets the batchCount and the batchStride fields of the sparse matrix descriptor spMatDescr.
cusparseCbsr2csr
This function converts a sparse matrix in BSR format that is defined by the three arrays bsrValA, bsrRowPtrA, and bsrColIndA) into a sparse matrix in CSR format that is defined by arrays csrValC, csrRowPtrC, and csrColIndC.
cusparseCbsric02
This function performs the solve phase of the incomplete-Cholesky factorization with 0 fill-in and no pivoting.
cusparseCbsric02_analysis
This function performs the analysis phase of the incomplete-Cholesky factorization with 0 fill-in and no pivoting
cusparseCbsric02_bufferSize
This function returns the size of a buffer used in computing the incomplete-Cholesky factorization with 0 fill-in and no pivoting
cusparseCbsric02_bufferSizeExt
cusparseCbsrilu02
This function performs the solve phase of the incomplete-LU factorization with 0 fill-in and no pivoting.
cusparseCbsrilu02_analysis
This function performs the analysis phase of the incomplete-LU factorization with 0 fill-in and no pivoting.
cusparseCbsrilu02_bufferSize
This function returns the size of the buffer used in computing the incomplete-LU factorization with 0 fill-in and no pivoting.
cusparseCbsrilu02_bufferSizeExt
cusparseCbsrilu02_numericBoost
The user can use a boost value to replace a numerical value in incomplete LU factorization. Parameter tol is used to determine a numerical zero, and boost_val is used to replace a numerical zero. The behavior is as follows:
cusparseCbsrmm
This function performs one of the following matrix-matrix operations:
cusparseCbsrmv
This function performs the matrix-vector operation
cusparseCbsrsm2_analysis
This function performs the analysis phase of bsrsm2(), a new sparse triangular linear system op(A)*op(X) =$\alpha$op(B).
cusparseCbsrsm2_bufferSize
This function returns size of buffer used in bsrsm2(), a new sparse triangular linear system op(A)*op(X)=$\alpha$op(B).
cusparseCbsrsm2_bufferSizeExt
cusparseCbsrsm2_solve
This function performs the solve phase of the solution of a sparse triangular linear system:
cusparseCbsrsv2_analysis
This function performs the analysis phase of bsrsv2, a new sparse triangular linear system op(A)*y =$\alpha$x.
cusparseCbsrsv2_bufferSize
This function returns size of the buffer used in bsrsv2, a new sparse triangular linear system op(A)*y =$\alpha$x.
cusparseCbsrsv2_bufferSizeExt
cusparseCbsrsv2_solve
This function performs the solve phase of bsrsv2, a new sparse triangular linear system op(A)*y =$\alpha$x.
cusparseCbsrxmv
This function performs a bsrmv and a mask operation
cusparseCcsr2bsr
cusparseCcsr2csr_compress
cusparseCcsr2csru
cusparseCcsr2gebsr
This function converts a sparse matrix A in CSR format (that is defined by arrays csrValA, csrRowPtrA, and csrColIndA) into a sparse matrix C in general BSR format (that is defined by the three arrays bsrValC, bsrRowPtrC, and bsrColIndC).
cusparseCcsr2gebsr_bufferSize
cusparseCcsr2gebsr_bufferSizeExt
cusparseCcsrcolor
This function performs the coloring of the adjacency graph associated with the matrix A stored in CSR format. The coloring is an assignment of colors (integer numbers) to nodes, such that neighboring nodes have distinct colors. An approximate coloring algorithm is used in this routine, and is stopped when a certain percentage of nodes has been colored. The rest of the nodes are assigned distinct colors (an increasing sequence of integers numbers, starting from the last integer used previously). The last two auxiliary routines can be used to extract the resulting number of colors, their assignment and the associated reordering. The reordering is such that nodes that have been assigned the same color are reordered to be next to each other.
cusparseCcsrgeam2
This function performs following matrix-matrix operation
cusparseCcsrgeam2_bufferSizeExt
cusparseCcsric02
This function performs the solve phase of the computing the incomplete-Cholesky factorization with $0$ fill-in and no pivoting:
cusparseCcsric02_analysis
This function performs the analysis phase of the incomplete-Cholesky factorization with $0$ fill-in and no pivoting:
cusparseCcsric02_bufferSize
This function returns size of buffer used in computing the incomplete-Cholesky factorization with $0$ fill-in and no pivoting:
cusparseCcsric02_bufferSizeExt
cusparseCcsrilu02
This function performs the solve phase of the incomplete-LU factorization with $0$ fill-in and no pivoting:
cusparseCcsrilu02_analysis
This function performs the analysis phase of the incomplete-LU factorization with $0$ fill-in and no pivoting:
cusparseCcsrilu02_bufferSize
This function returns size of the buffer used in computing the incomplete-LU factorization with $0$ fill-in and no pivoting:
cusparseCcsrilu02_bufferSizeExt
cusparseCcsrilu02_numericBoost
The user can use a boost value to replace a numerical value in incomplete LU factorization. The tol is used to determine a numerical zero, and the boost_val is used to replace a numerical zero. The behavior is
cusparseCcsru2csr
cusparseCcsru2csr_bufferSizeExt
cusparseCgebsr2csr
This function converts a sparse matrix in BSR format that is defined by the three arrays bsrValA, bsrRowPtrA, and bsrColIndA) into a sparse matrix in CSR format that is defined by arrays csrValC, csrRowPtrC, and csrColIndC.
cusparseCgebsr2gebsc
This function can be seen as the same as csr2csc() when each block of size rowBlockDim*colBlockDim is regarded as a scalar.
cusparseCgebsr2gebsc_bufferSize
cusparseCgebsr2gebsc_bufferSizeExt
cusparseCgebsr2gebsr
This function converts a sparse matrix in general BSR format that is defined by the three arrays bsrValA, bsrRowPtrA, and bsrColIndA into a sparse matrix in another general BSR format that is defined by arrays bsrValC, bsrRowPtrC, and bsrColIndC.
cusparseCgebsr2gebsr_bufferSize
cusparseCgebsr2gebsr_bufferSizeExt
cusparseCgemvi
This function performs the matrix-vector operation
cusparseCgemvi_bufferSize
cusparseCgpsvInterleavedBatch
This function computes the solution of multiple penta-diagonal linear systems for i=0,…,batchCount:
cusparseCgpsvInterleavedBatch_bufferSizeExt
cusparseCgtsv2
This function computes the solution of a tridiagonal linear system with multiple right-hand sides:
cusparseCgtsv2StridedBatch
This function computes the solution of multiple tridiagonal linear systems for i=0,…,batchCount:
cusparseCgtsv2StridedBatch_bufferSizeExt
This function returns the size of the buffer used in gtsv2StridedBatch which computes the solution of multiple tridiagonal linear systems for i=0,…,batchCount:
cusparseCgtsv2_bufferSizeExt
cusparseCgtsv2_nopivot
This function computes the solution of a tridiagonal linear system with multiple right-hand sides:
cusparseCgtsv2_nopivot_bufferSizeExt
This function returns the size of the buffer used in gtsv2_nopivot which computes the solution of a tridiagonal linear system with multiple right-hand sides.
cusparseCgtsvInterleavedBatch
This function computes the solution of multiple tridiagonal linear systems for i=0,…,batchCount:
cusparseCgtsvInterleavedBatch_bufferSizeExt
cusparseCnnz
This function computes the number of nonzero elements per row or column and the total number of nonzero elements in a dense matrix.
cusparseCnnz_compress
This function is the step one to convert from csr format to compressed csr format.
cusparseConstBlockedEllGet
cusparseConstCooGet
cusparseConstCscGet
cusparseConstCsrGet
cusparseConstDnMatGet
cusparseConstDnMatGetValues
cusparseConstDnVecGet
cusparseConstDnVecGetValues
cusparseConstSpMatGetValues
cusparseConstSpVecGet
cusparseConstSpVecGetValues
cusparseCooGet
This function returns the fields of the sparse matrix descriptor spMatDescr stored in COO format (Array of Structures layout).
cusparseCooSetPointers
This function sets the pointers of the sparse matrix descriptor spMatDescr.
cusparseCooSetStridedBatch
This function sets the batchCount and the batchStride fields of the sparse matrix descriptor spMatDescr.
cusparseCreate
This function initializes the cuSPARSE library and creates a handle on the cuSPARSE context. It must be called before any other cuSPARSE API function is invoked. It allocates hardware resources necessary for accessing the GPU.
cusparseCreateBlockedEll
This function initializes the sparse matrix descriptor spMatDescr for the Blocked-Ellpack (ELL) format.
cusparseCreateBsr
This function initializes the sparse matrix descriptor spMatDescr for the Block Compressed Row (BSR) format.
cusparseCreateBsric02InfoDeprecated
This function creates and initializes the solve and analysis structure of block incomplete Cholesky to default values.
cusparseCreateBsrilu02InfoDeprecated
This function creates and initializes the solve and analysis structure of block incomplete LU to default values.
cusparseCreateBsrsm2InfoDeprecated
This function creates and initializes the solve and analysis structure of bsrsm2 to default values.
cusparseCreateBsrsv2InfoDeprecated
This function creates and initializes the solve and analysis structure of bsrsv2 to default values.
cusparseCreateColorInfoDeprecated
This function creates and initializes the cusparseColorInfo_t structure to default values.
cusparseCreateConstBlockedEll
cusparseCreateConstBsr
cusparseCreateConstCoo
cusparseCreateConstCsc
cusparseCreateConstCsr
cusparseCreateConstDnMat
cusparseCreateConstDnVec
cusparseCreateConstSlicedEll
cusparseCreateConstSpVec
cusparseCreateCoo
This function initializes the sparse matrix descriptor spMatDescr in the COO format (Structure of Arrays layout).
cusparseCreateCsc
This function initializes the sparse matrix descriptor spMatDescr in the CSC format.
cusparseCreateCsr
This function initializes the sparse matrix descriptor spMatDescr in the CSR format.
cusparseCreateCsric02InfoDeprecated
This function creates and initializes the solve and analysis structure of incomplete Cholesky to default values.
cusparseCreateCsrilu02InfoDeprecated
This function creates and initializes the solve and analysis structure of incomplete LU to default values.
cusparseCreateCsru2csrInfo
cusparseCreateDnMat
The function initializes the dense matrix descriptor dnMatDescr.
cusparseCreateDnVec
This function initializes the dense vector descriptor dnVecDescr.
cusparseCreateIdentityPermutationDeprecated
This function creates an identity map. The output parameter p represents such map by p = 0:1:(n-1).
cusparseCreateMatDescr
This function initializes the matrix descriptor. It sets the fields MatrixType and IndexBase to the default values cusparseMatrixType_t::CUSPARSE_MATRIX_TYPE_GENERAL and cusparseIndexBase_t::CUSPARSE_INDEX_BASE_ZERO, respectively, while leaving other fields uninitialized.
cusparseCreatePruneInfoDeprecated
This function creates and initializes structure of prune to default values.
cusparseCreateSlicedEll
This function initializes the sparse matrix descriptor spMatDescr for the Sliced Ellpack (SELL) format.
cusparseCreateSpVec
This function initializes the sparse matrix descriptor spVecDescr.
cusparseCscGet
This function returns the fields of the sparse matrix descriptor spMatDescr stored in CSC format.
cusparseCscSetPointers
This function sets the pointers of the sparse matrix descriptor spMatDescr.
cusparseCsr2cscEx2
This function converts a sparse matrix in CSR format (that is defined by the three arrays csrVal, csrRowPtr, and csrColInd) into a sparse matrix in CSC format (that is defined by arrays cscVal, cscRowInd, and cscColPtr). The resulting matrix can also be seen as the transpose of the original sparse matrix. Notice that this routine can also be used to convert a matrix in CSC format into a matrix in CSR format.
cusparseCsr2cscEx2_bufferSize
cusparseCsrGet
This function returns the fields of the sparse matrix descriptor spMatDescr stored in CSR format.
cusparseCsrSetPointers
This function sets the pointers of the sparse matrix descriptor spMatDescr.
cusparseCsrSetStridedBatch
This function sets the batchCount and the batchStride fields of the sparse matrix descriptor spMatDescr.
cusparseDbsr2csr
This function converts a sparse matrix in BSR format that is defined by the three arrays bsrValA, bsrRowPtrA, and bsrColIndA) into a sparse matrix in CSR format that is defined by arrays csrValC, csrRowPtrC, and csrColIndC.
cusparseDbsric02
This function performs the solve phase of the incomplete-Cholesky factorization with 0 fill-in and no pivoting.
cusparseDbsric02_analysis
This function performs the analysis phase of the incomplete-Cholesky factorization with 0 fill-in and no pivoting
cusparseDbsric02_bufferSize
This function returns the size of a buffer used in computing the incomplete-Cholesky factorization with 0 fill-in and no pivoting
cusparseDbsric02_bufferSizeExt
cusparseDbsrilu02
This function performs the solve phase of the incomplete-LU factorization with 0 fill-in and no pivoting.
cusparseDbsrilu02_analysis
This function performs the analysis phase of the incomplete-LU factorization with 0 fill-in and no pivoting.
cusparseDbsrilu02_bufferSize
This function returns the size of the buffer used in computing the incomplete-LU factorization with 0 fill-in and no pivoting.
cusparseDbsrilu02_bufferSizeExt
cusparseDbsrilu02_numericBoost
The user can use a boost value to replace a numerical value in incomplete LU factorization. Parameter tol is used to determine a numerical zero, and boost_val is used to replace a numerical zero. The behavior is as follows:
cusparseDbsrmm
This function performs one of the following matrix-matrix operations:
cusparseDbsrmv
This function performs the matrix-vector operation
cusparseDbsrsm2_analysis
This function performs the analysis phase of bsrsm2(), a new sparse triangular linear system op(A)*op(X) =$\alpha$op(B).
cusparseDbsrsm2_bufferSize
This function returns size of buffer used in bsrsm2(), a new sparse triangular linear system op(A)*op(X)=$\alpha$op(B).
cusparseDbsrsm2_bufferSizeExt
cusparseDbsrsm2_solve
This function performs the solve phase of the solution of a sparse triangular linear system:
cusparseDbsrsv2_analysis
This function performs the analysis phase of bsrsv2, a new sparse triangular linear system op(A)*y =$\alpha$x.
cusparseDbsrsv2_bufferSize
This function returns size of the buffer used in bsrsv2, a new sparse triangular linear system op(A)*y =$\alpha$x.
cusparseDbsrsv2_bufferSizeExt
cusparseDbsrsv2_solve
This function performs the solve phase of bsrsv2, a new sparse triangular linear system op(A)*y =$\alpha$x.
cusparseDbsrxmv
This function performs a bsrmv and a mask operation
cusparseDcsr2bsr
cusparseDcsr2csr_compress
cusparseDcsr2csru
cusparseDcsr2gebsr
This function converts a sparse matrix A in CSR format (that is defined by arrays csrValA, csrRowPtrA, and csrColIndA) into a sparse matrix C in general BSR format (that is defined by the three arrays bsrValC, bsrRowPtrC, and bsrColIndC).
cusparseDcsr2gebsr_bufferSize
cusparseDcsr2gebsr_bufferSizeExt
cusparseDcsrcolor
This function performs the coloring of the adjacency graph associated with the matrix A stored in CSR format. The coloring is an assignment of colors (integer numbers) to nodes, such that neighboring nodes have distinct colors. An approximate coloring algorithm is used in this routine, and is stopped when a certain percentage of nodes has been colored. The rest of the nodes are assigned distinct colors (an increasing sequence of integers numbers, starting from the last integer used previously). The last two auxiliary routines can be used to extract the resulting number of colors, their assignment and the associated reordering. The reordering is such that nodes that have been assigned the same color are reordered to be next to each other.
cusparseDcsrgeam2
This function performs following matrix-matrix operation
cusparseDcsrgeam2_bufferSizeExt
cusparseDcsric02
This function performs the solve phase of the computing the incomplete-Cholesky factorization with $0$ fill-in and no pivoting:
cusparseDcsric02_analysis
This function performs the analysis phase of the incomplete-Cholesky factorization with $0$ fill-in and no pivoting:
cusparseDcsric02_bufferSize
This function returns size of buffer used in computing the incomplete-Cholesky factorization with $0$ fill-in and no pivoting:
cusparseDcsric02_bufferSizeExt
cusparseDcsrilu02
This function performs the solve phase of the incomplete-LU factorization with $0$ fill-in and no pivoting:
cusparseDcsrilu02_analysis
This function performs the analysis phase of the incomplete-LU factorization with $0$ fill-in and no pivoting:
cusparseDcsrilu02_bufferSize
This function returns size of the buffer used in computing the incomplete-LU factorization with $0$ fill-in and no pivoting:
cusparseDcsrilu02_bufferSizeExt
cusparseDcsrilu02_numericBoost
The user can use a boost value to replace a numerical value in incomplete LU factorization. The tol is used to determine a numerical zero, and the boost_val is used to replace a numerical zero. The behavior is
cusparseDcsru2csr
cusparseDcsru2csr_bufferSizeExt
cusparseDenseToSparse_analysis
cusparseDenseToSparse_bufferSize
cusparseDenseToSparse_convert
cusparseDestroy
This function releases CPU-side resources used by the cuSPARSE library. The release of GPU-side resources may be deferred until the application shuts down.
cusparseDestroyBsric02InfoDeprecated
This function destroys and releases any memory required by the structure.
cusparseDestroyBsrilu02InfoDeprecated
This function destroys and releases any memory required by the structure.
cusparseDestroyBsrsm2InfoDeprecated
This function destroys and releases any memory required by the structure.
cusparseDestroyBsrsv2InfoDeprecated
This function destroys and releases any memory required by the structure.
cusparseDestroyColorInfoDeprecated
This function destroys and releases any memory required by the structure.
cusparseDestroyCsric02InfoDeprecated
This function destroys and releases any memory required by the structure.
cusparseDestroyCsrilu02InfoDeprecated
This function destroys and releases any memory required by the structure.
cusparseDestroyCsru2csrInfo
cusparseDestroyDnMat
This function releases the host memory allocated for the dense matrix descriptor dnMatDescr.
cusparseDestroyDnVec
This function releases the host memory allocated for the dense vector descriptor dnVecDescr.
cusparseDestroyMatDescr
This function releases the memory allocated for the matrix descriptor.
cusparseDestroyPruneInfoDeprecated
This function destroys and releases any memory required by the structure.
cusparseDestroySpMat
This function releases the host memory allocated for the sparse matrix descriptor spMatDescr.
cusparseDestroySpVec
This function releases the host memory allocated for the sparse vector descriptor spVecDescr.
cusparseDgebsr2csr
This function converts a sparse matrix in BSR format that is defined by the three arrays bsrValA, bsrRowPtrA, and bsrColIndA) into a sparse matrix in CSR format that is defined by arrays csrValC, csrRowPtrC, and csrColIndC.
cusparseDgebsr2gebsc
This function can be seen as the same as csr2csc() when each block of size rowBlockDim*colBlockDim is regarded as a scalar.
cusparseDgebsr2gebsc_bufferSize
cusparseDgebsr2gebsc_bufferSizeExt
cusparseDgebsr2gebsr
This function converts a sparse matrix in general BSR format that is defined by the three arrays bsrValA, bsrRowPtrA, and bsrColIndA into a sparse matrix in another general BSR format that is defined by arrays bsrValC, bsrRowPtrC, and bsrColIndC.
cusparseDgebsr2gebsr_bufferSize
cusparseDgebsr2gebsr_bufferSizeExt
cusparseDgemvi
This function performs the matrix-vector operation
cusparseDgemvi_bufferSize
cusparseDgpsvInterleavedBatch
This function computes the solution of multiple penta-diagonal linear systems for i=0,…,batchCount:
cusparseDgpsvInterleavedBatch_bufferSizeExt
cusparseDgtsv2
This function computes the solution of a tridiagonal linear system with multiple right-hand sides:
cusparseDgtsv2StridedBatch
This function computes the solution of multiple tridiagonal linear systems for i=0,…,batchCount:
cusparseDgtsv2StridedBatch_bufferSizeExt
This function returns the size of the buffer used in gtsv2StridedBatch which computes the solution of multiple tridiagonal linear systems for i=0,…,batchCount:
cusparseDgtsv2_bufferSizeExt
cusparseDgtsv2_nopivot
This function computes the solution of a tridiagonal linear system with multiple right-hand sides:
cusparseDgtsv2_nopivot_bufferSizeExt
This function returns the size of the buffer used in gtsv2_nopivot which computes the solution of a tridiagonal linear system with multiple right-hand sides.
cusparseDgtsvInterleavedBatch
This function computes the solution of multiple tridiagonal linear systems for i=0,…,batchCount:
cusparseDgtsvInterleavedBatch_bufferSizeExt
cusparseDnMatGet
This function returns the fields of the dense matrix descriptor dnMatDescr.
cusparseDnMatGetStridedBatch
The function returns the number of batches and the batch stride of the dense matrix descriptor dnMatDescr.
cusparseDnMatGetValues
This function returns the values field of the dense matrix descriptor dnMatDescr.
cusparseDnMatSetStridedBatch
The function sets the number of batches and the batch stride of the dense matrix descriptor dnMatDescr.
cusparseDnMatSetValues
This function sets the values field of the dense matrix descriptor dnMatDescr.
cusparseDnVecGet
This function returns the fields of the dense vector descriptor dnVecDescr.
cusparseDnVecGetValues
This function returns the values field of the dense vector descriptor dnVecDescr.
cusparseDnVecSetValues
This function sets the values field of the dense vector descriptor dnVecDescr.
cusparseDnnz
This function computes the number of nonzero elements per row or column and the total number of nonzero elements in a dense matrix.
cusparseDnnz_compress
This function is the step one to convert from csr format to compressed csr format.
cusparseDpruneCsr2csr
cusparseDpruneCsr2csrByPercentage
cusparseDpruneCsr2csrByPercentage_bufferSizeExt
cusparseDpruneCsr2csrNnz
cusparseDpruneCsr2csrNnzByPercentage
cusparseDpruneCsr2csr_bufferSizeExt
cusparseDpruneDense2csr
cusparseDpruneDense2csrByPercentage
cusparseDpruneDense2csrByPercentage_bufferSizeExt
cusparseDpruneDense2csrNnz
cusparseDpruneDense2csrNnzByPercentage
cusparseDpruneDense2csr_bufferSizeExt
cusparseGather
The function gathers the elements of the dense vector vecY into the sparse vector vecX
cusparseGetErrorName
The function returns the string representation of an error code enum name. If the error code is not recognized, “unrecognized error code” is returned.
cusparseGetErrorString
Parameters
cusparseGetMatDiagType
This function returns the DiagType field of the matrix descriptor descrA.
cusparseGetMatFillMode
This function returns the FillMode field of the matrix descriptor descrA.
cusparseGetMatIndexBase
This function returns the IndexBase field of the matrix descriptor descrA.
cusparseGetMatType
This function returns the MatrixType field of the matrix descriptor descrA.
cusparseGetPointerMode
This function obtains the pointer mode used by the cuSPARSE library. Please see the section on the cusparsePointerMode_t type for more details.
cusparseGetProperty
The function returns the value of the requested property. Refer to libraryPropertyType for supported types.
cusparseGetStream
This function gets the cuSPARSE library stream, which is being used to to execute all calls to the cuSPARSE library functions. If the cuSPARSE library stream is not set, all kernels use the default NULL stream.
cusparseGetVersion
This function returns the version number of the cuSPARSE library.
cusparseLoggerForceDisable
cusparseLoggerOpenFile
Experimental: The function opens a logging output file in the given path.
cusparseLoggerSetCallback
Experimental: The function sets the logging callback function.
cusparseLoggerSetFile
Experimental: The function sets the logging output file. Note: once registered using this function call, the provided file handle must not be closed unless the function is called again to switch to a different file handle.
cusparseLoggerSetLevel
Experimental: The function sets the value of the logging level. path.
cusparseLoggerSetMask
Experimental: The function sets the value of the logging mask.
cusparseRotDeprecated
The function computes the Givens rotation matrix
cusparseSDDMM
This function performs the multiplication of matA and matB, followed by an element-wise multiplication with the sparsity pattern of matC. Formally, it performs the following operation:
cusparseSDDMM_bufferSize
cusparseSDDMM_preprocess
cusparseSbsr2csr
This function converts a sparse matrix in BSR format that is defined by the three arrays bsrValA, bsrRowPtrA, and bsrColIndA) into a sparse matrix in CSR format that is defined by arrays csrValC, csrRowPtrC, and csrColIndC.
cusparseSbsric02
This function performs the solve phase of the incomplete-Cholesky factorization with 0 fill-in and no pivoting.
cusparseSbsric02_analysis
This function performs the analysis phase of the incomplete-Cholesky factorization with 0 fill-in and no pivoting
cusparseSbsric02_bufferSize
This function returns the size of a buffer used in computing the incomplete-Cholesky factorization with 0 fill-in and no pivoting
cusparseSbsric02_bufferSizeExt
cusparseSbsrilu02
This function performs the solve phase of the incomplete-LU factorization with 0 fill-in and no pivoting.
cusparseSbsrilu02_analysis
This function performs the analysis phase of the incomplete-LU factorization with 0 fill-in and no pivoting.
cusparseSbsrilu02_bufferSize
This function returns the size of the buffer used in computing the incomplete-LU factorization with 0 fill-in and no pivoting.
cusparseSbsrilu02_bufferSizeExt
cusparseSbsrilu02_numericBoost
The user can use a boost value to replace a numerical value in incomplete LU factorization. Parameter tol is used to determine a numerical zero, and boost_val is used to replace a numerical zero. The behavior is as follows:
cusparseSbsrmm
This function performs one of the following matrix-matrix operations:
cusparseSbsrmv
This function performs the matrix-vector operation
cusparseSbsrsm2_analysis
This function performs the analysis phase of bsrsm2(), a new sparse triangular linear system op(A)*op(X) =$\alpha$op(B).
cusparseSbsrsm2_bufferSize
This function returns size of buffer used in bsrsm2(), a new sparse triangular linear system op(A)*op(X)=$\alpha$op(B).
cusparseSbsrsm2_bufferSizeExt
cusparseSbsrsm2_solve
This function performs the solve phase of the solution of a sparse triangular linear system:
cusparseSbsrsv2_analysis
This function performs the analysis phase of bsrsv2, a new sparse triangular linear system op(A)*y =$\alpha$x.
cusparseSbsrsv2_bufferSize
This function returns size of the buffer used in bsrsv2, a new sparse triangular linear system op(A)*y =$\alpha$x.
cusparseSbsrsv2_bufferSizeExt
cusparseSbsrsv2_solve
This function performs the solve phase of bsrsv2, a new sparse triangular linear system op(A)*y =$\alpha$x.
cusparseSbsrxmv
This function performs a bsrmv and a mask operation
cusparseScatter
The function scatters the elements of the sparse vector vecX into the dense vector vecY
cusparseScsr2bsr
cusparseScsr2csr_compress
cusparseScsr2csru
cusparseScsr2gebsr
This function converts a sparse matrix A in CSR format (that is defined by arrays csrValA, csrRowPtrA, and csrColIndA) into a sparse matrix C in general BSR format (that is defined by the three arrays bsrValC, bsrRowPtrC, and bsrColIndC).
cusparseScsr2gebsr_bufferSize
cusparseScsr2gebsr_bufferSizeExt
cusparseScsrcolor
This function performs the coloring of the adjacency graph associated with the matrix A stored in CSR format. The coloring is an assignment of colors (integer numbers) to nodes, such that neighboring nodes have distinct colors. An approximate coloring algorithm is used in this routine, and is stopped when a certain percentage of nodes has been colored. The rest of the nodes are assigned distinct colors (an increasing sequence of integers numbers, starting from the last integer used previously). The last two auxiliary routines can be used to extract the resulting number of colors, their assignment and the associated reordering. The reordering is such that nodes that have been assigned the same color are reordered to be next to each other.
cusparseScsrgeam2
This function performs following matrix-matrix operation
cusparseScsrgeam2_bufferSizeExt
cusparseScsric02
This function performs the solve phase of the computing the incomplete-Cholesky factorization with $0$ fill-in and no pivoting:
cusparseScsric02_analysis
This function performs the analysis phase of the incomplete-Cholesky factorization with $0$ fill-in and no pivoting:
cusparseScsric02_bufferSize
This function returns size of buffer used in computing the incomplete-Cholesky factorization with $0$ fill-in and no pivoting:
cusparseScsric02_bufferSizeExt
cusparseScsrilu02
This function performs the solve phase of the incomplete-LU factorization with $0$ fill-in and no pivoting:
cusparseScsrilu02_analysis
This function performs the analysis phase of the incomplete-LU factorization with $0$ fill-in and no pivoting:
cusparseScsrilu02_bufferSize
This function returns size of the buffer used in computing the incomplete-LU factorization with $0$ fill-in and no pivoting:
cusparseScsrilu02_bufferSizeExt
cusparseScsrilu02_numericBoost
The user can use a boost value to replace a numerical value in incomplete LU factorization. The tol is used to determine a numerical zero, and the boost_val is used to replace a numerical zero. The behavior is
cusparseScsru2csr
cusparseScsru2csr_bufferSizeExt
cusparseSetMatDiagType
This function sets the DiagType field of the matrix descriptor descrA.
cusparseSetMatFillMode
This function sets the FillMode field of the matrix descriptor descrA.
cusparseSetMatIndexBase
This function sets the IndexBase field of the matrix descriptor descrA.
cusparseSetMatType
This function sets the MatrixType field of the matrix descriptor descrA.
cusparseSetPointerMode
This function sets the pointer mode used by the cuSPARSE library. The default is for the values to be passed by reference on the host. Please see the section on the cublasPointerMode_t type for more details.
cusparseSetStream
This function sets the stream to be used by the cuSPARSE library to execute its routines.
cusparseSgebsr2csr
This function converts a sparse matrix in BSR format that is defined by the three arrays bsrValA, bsrRowPtrA, and bsrColIndA) into a sparse matrix in CSR format that is defined by arrays csrValC, csrRowPtrC, and csrColIndC.
cusparseSgebsr2gebsc
This function can be seen as the same as csr2csc() when each block of size rowBlockDim*colBlockDim is regarded as a scalar.
cusparseSgebsr2gebsc_bufferSize
cusparseSgebsr2gebsc_bufferSizeExt
cusparseSgebsr2gebsr
This function converts a sparse matrix in general BSR format that is defined by the three arrays bsrValA, bsrRowPtrA, and bsrColIndA into a sparse matrix in another general BSR format that is defined by arrays bsrValC, bsrRowPtrC, and bsrColIndC.
cusparseSgebsr2gebsr_bufferSize
cusparseSgebsr2gebsr_bufferSizeExt
cusparseSgemvi
This function performs the matrix-vector operation
cusparseSgemvi_bufferSize
cusparseSgpsvInterleavedBatch
This function computes the solution of multiple penta-diagonal linear systems for i=0,…,batchCount:
cusparseSgpsvInterleavedBatch_bufferSizeExt
cusparseSgtsv2
This function computes the solution of a tridiagonal linear system with multiple right-hand sides:
cusparseSgtsv2StridedBatch
This function computes the solution of multiple tridiagonal linear systems for i=0,…,batchCount:
cusparseSgtsv2StridedBatch_bufferSizeExt
This function returns the size of the buffer used in gtsv2StridedBatch which computes the solution of multiple tridiagonal linear systems for i=0,…,batchCount:
cusparseSgtsv2_bufferSizeExt
cusparseSgtsv2_nopivot
This function computes the solution of a tridiagonal linear system with multiple right-hand sides:
cusparseSgtsv2_nopivot_bufferSizeExt
This function returns the size of the buffer used in gtsv2_nopivot which computes the solution of a tridiagonal linear system with multiple right-hand sides.
cusparseSgtsvInterleavedBatch
This function computes the solution of multiple tridiagonal linear systems for i=0,…,batchCount:
cusparseSgtsvInterleavedBatch_bufferSizeExt
cusparseSnnz
This function computes the number of nonzero elements per row or column and the total number of nonzero elements in a dense matrix.
cusparseSnnz_compress
This function is the step one to convert from csr format to compressed csr format.
cusparseSpGEMM_compute
cusparseSpGEMM_copy
cusparseSpGEMM_createDescr
cusparseSpGEMM_destroyDescr
cusparseSpGEMM_estimateMemory
cusparseSpGEMM_getNumProducts
cusparseSpGEMM_workEstimation
cusparseSpGEMMreuse_compute
cusparseSpGEMMreuse_copy
cusparseSpGEMMreuse_nnz
This function computes the number of nonzero elements per row or column and the total number of nonzero elements in a dense matrix.
cusparseSpGEMMreuse_workEstimation
cusparseSpMM
The function performs the multiplication of a sparse matrix matA and a dense matrix matB.
cusparseSpMMOp
NOTE 1: NVRTC and nvJitLink are not currently available on Arm64 Android platforms.
cusparseSpMMOp_createPlan
cusparseSpMMOp_destroyPlan
cusparseSpMM_bufferSize
cusparseSpMM_preprocess
cusparseSpMV
This function performs the multiplication of a sparse matrix matA and a dense vector vecX
cusparseSpMV_bufferSize
cusparseSpMV_preprocess
cusparseSpMatGetAttribute
The function gets the attributes of the sparse matrix descriptor spMatDescr.
cusparseSpMatGetFormat
This function returns the format field of the sparse matrix descriptor spMatDescr.
cusparseSpMatGetIndexBase
This function returns the idxBase field of the sparse matrix descriptor spMatDescr.
cusparseSpMatGetSize
This function returns the sizes of the sparse matrix spMatDescr.
cusparseSpMatGetStridedBatch
This function returns the batchCount field of the sparse matrix descriptor spMatDescr.
cusparseSpMatGetValues
This function returns the values field of the sparse matrix descriptor spMatDescr.
cusparseSpMatSetAttribute
The function sets the attributes of the sparse matrix descriptor spMatDescr
cusparseSpMatSetValues
This function sets the values field of the sparse matrix descriptor spMatDescr.
cusparseSpSM_analysis
cusparseSpSM_bufferSize
cusparseSpSM_createDescr
cusparseSpSM_destroyDescr
cusparseSpSM_solve
cusparseSpSM_updateMatrix
cusparseSpSV_analysis
cusparseSpSV_bufferSize
cusparseSpSV_createDescr
cusparseSpSV_destroyDescr
cusparseSpSV_solve
cusparseSpSV_updateMatrix
cusparseSpVVDeprecated
The function computes the inner dot product of a sparse vector vecX and a dense vector vecY
cusparseSpVV_bufferSize
cusparseSpVecGet
This function returns the fields of the sparse vector descriptor spVecDescr.
cusparseSpVecGetIndexBase
This function returns the idxBase field of the sparse vector descriptor spVecDescr.
cusparseSpVecGetValues
This function returns the values field of the sparse vector descriptor spVecDescr.
cusparseSpVecSetValues
This function sets the values field of the sparse vector descriptor spVecDescr.
cusparseSparseToDense
The function converts the sparse matrix matA in CSR, CSC, or COO format into its dense representation matB. Blocked-ELL is not currently supported.
cusparseSparseToDense_bufferSize
cusparseSpruneCsr2csr
cusparseSpruneCsr2csrByPercentage
cusparseSpruneCsr2csrByPercentage_bufferSizeExt
cusparseSpruneCsr2csrNnz
cusparseSpruneCsr2csrNnzByPercentage
cusparseSpruneCsr2csr_bufferSizeExt
cusparseSpruneDense2csr
cusparseSpruneDense2csrByPercentage
cusparseSpruneDense2csrByPercentage_bufferSizeExt
cusparseSpruneDense2csrNnz
cusparseSpruneDense2csrNnzByPercentage
cusparseSpruneDense2csr_bufferSizeExt
cusparseXbsric02_zeroPivotDeprecated
If the returned error code is cusparseStatus_t::CUSPARSE_STATUS_ZERO_PIVOT, position=j means A(j,j) has either a structural zero or a numerical zero (the block is not positive definite). Otherwise position=-1.
cusparseXbsrilu02_zeroPivotDeprecated
If the returned error code is cusparseStatus_t::CUSPARSE_STATUS_ZERO_PIVOT, position=j means A(j,j) has either a structural zero or a numerical zero (the block is not invertible). Otherwise position=-1.
cusparseXbsrsm2_zeroPivotDeprecated
If the returned error code is cusparseStatus_t::CUSPARSE_STATUS_ZERO_PIVOT, position=j means A(j,j) is either a structural zero or a numerical zero (singular block). Otherwise position=-1.
cusparseXbsrsv2_zeroPivotDeprecated
If the returned error code is cusparseStatus_t::CUSPARSE_STATUS_ZERO_PIVOT, position=j means A(j,j) is either structural zero or numerical zero (singular block). Otherwise position=-1.
cusparseXcoo2csr
This function converts the array containing the uncompressed row indices (corresponding to COO format) into an array of compressed row pointers (corresponding to CSR format).
cusparseXcoosortByColumn
cusparseXcoosortByRow
cusparseXcoosort_bufferSizeExt
cusparseXcscsort
This function sorts CSC format. The stable sorting is in-place.
cusparseXcscsort_bufferSizeExt
cusparseXcsr2bsrNnz
cusparseXcsr2coo
This function converts the array containing the compressed row pointers (corresponding to CSR format) into an array of uncompressed row indices (corresponding to COO format).
cusparseXcsr2gebsrNnz
cusparseXcsrgeam2Nnz
cusparseXcsric02_zeroPivotDeprecated
If the returned error code is cusparseStatus_t::CUSPARSE_STATUS_ZERO_PIVOT, position=j means A(j,j) has either a structural zero or a numerical zero; otherwise, position=-1.
cusparseXcsrilu02_zeroPivotDeprecated
If the returned error code is cusparseStatus_t::CUSPARSE_STATUS_ZERO_PIVOT, position=j means A(j,j) has either a structural zero or a numerical zero; otherwise, position=-1.
cusparseXcsrsort
This function sorts CSR format. The stable sorting is in-place.
cusparseXcsrsort_bufferSizeExt
cusparseXgebsr2csr
This function converts a sparse matrix in BSR format that is defined by the three arrays bsrValA, bsrRowPtrA, and bsrColIndA) into a sparse matrix in CSR format that is defined by arrays csrValC, csrRowPtrC, and csrColIndC.
cusparseXgebsr2gebsrNnz
cusparseZbsr2csr
This function converts a sparse matrix in BSR format that is defined by the three arrays bsrValA, bsrRowPtrA, and bsrColIndA) into a sparse matrix in CSR format that is defined by arrays csrValC, csrRowPtrC, and csrColIndC.
cusparseZbsric02
This function performs the solve phase of the incomplete-Cholesky factorization with 0 fill-in and no pivoting.
cusparseZbsric02_analysis
This function performs the analysis phase of the incomplete-Cholesky factorization with 0 fill-in and no pivoting
cusparseZbsric02_bufferSize
This function returns the size of a buffer used in computing the incomplete-Cholesky factorization with 0 fill-in and no pivoting
cusparseZbsric02_bufferSizeExt
cusparseZbsrilu02
This function performs the solve phase of the incomplete-LU factorization with 0 fill-in and no pivoting.
cusparseZbsrilu02_analysis
This function performs the analysis phase of the incomplete-LU factorization with 0 fill-in and no pivoting.
cusparseZbsrilu02_bufferSize
This function returns the size of the buffer used in computing the incomplete-LU factorization with 0 fill-in and no pivoting.
cusparseZbsrilu02_bufferSizeExt
cusparseZbsrilu02_numericBoost
The user can use a boost value to replace a numerical value in incomplete LU factorization. Parameter tol is used to determine a numerical zero, and boost_val is used to replace a numerical zero. The behavior is as follows:
cusparseZbsrmm
This function performs one of the following matrix-matrix operations:
cusparseZbsrmv
This function performs the matrix-vector operation
cusparseZbsrsm2_analysis
This function performs the analysis phase of bsrsm2(), a new sparse triangular linear system op(A)*op(X) =$\alpha$op(B).
cusparseZbsrsm2_bufferSize
This function returns size of buffer used in bsrsm2(), a new sparse triangular linear system op(A)*op(X)=$\alpha$op(B).
cusparseZbsrsm2_bufferSizeExt
cusparseZbsrsm2_solve
This function performs the solve phase of the solution of a sparse triangular linear system:
cusparseZbsrsv2_analysis
This function performs the analysis phase of bsrsv2, a new sparse triangular linear system op(A)*y =$\alpha$x.
cusparseZbsrsv2_bufferSize
This function returns size of the buffer used in bsrsv2, a new sparse triangular linear system op(A)*y =$\alpha$x.
cusparseZbsrsv2_bufferSizeExt
cusparseZbsrsv2_solve
This function performs the solve phase of bsrsv2, a new sparse triangular linear system op(A)*y =$\alpha$x.
cusparseZbsrxmv
This function performs a bsrmv and a mask operation
cusparseZcsr2bsr
cusparseZcsr2csr_compress
cusparseZcsr2csru
cusparseZcsr2gebsr
This function converts a sparse matrix A in CSR format (that is defined by arrays csrValA, csrRowPtrA, and csrColIndA) into a sparse matrix C in general BSR format (that is defined by the three arrays bsrValC, bsrRowPtrC, and bsrColIndC).
cusparseZcsr2gebsr_bufferSize
cusparseZcsr2gebsr_bufferSizeExt
cusparseZcsrcolor
This function performs the coloring of the adjacency graph associated with the matrix A stored in CSR format. The coloring is an assignment of colors (integer numbers) to nodes, such that neighboring nodes have distinct colors. An approximate coloring algorithm is used in this routine, and is stopped when a certain percentage of nodes has been colored. The rest of the nodes are assigned distinct colors (an increasing sequence of integers numbers, starting from the last integer used previously). The last two auxiliary routines can be used to extract the resulting number of colors, their assignment and the associated reordering. The reordering is such that nodes that have been assigned the same color are reordered to be next to each other.
cusparseZcsrgeam2
This function performs following matrix-matrix operation
cusparseZcsrgeam2_bufferSizeExt
cusparseZcsric02
This function performs the solve phase of the computing the incomplete-Cholesky factorization with $0$ fill-in and no pivoting:
cusparseZcsric02_analysis
This function performs the analysis phase of the incomplete-Cholesky factorization with $0$ fill-in and no pivoting:
cusparseZcsric02_bufferSize
This function returns size of buffer used in computing the incomplete-Cholesky factorization with $0$ fill-in and no pivoting:
cusparseZcsric02_bufferSizeExt
cusparseZcsrilu02
This function performs the solve phase of the incomplete-LU factorization with $0$ fill-in and no pivoting:
cusparseZcsrilu02_analysis
This function performs the analysis phase of the incomplete-LU factorization with $0$ fill-in and no pivoting:
cusparseZcsrilu02_bufferSize
This function returns size of the buffer used in computing the incomplete-LU factorization with $0$ fill-in and no pivoting:
cusparseZcsrilu02_bufferSizeExt
cusparseZcsrilu02_numericBoost
The user can use a boost value to replace a numerical value in incomplete LU factorization. The tol is used to determine a numerical zero, and the boost_val is used to replace a numerical zero. The behavior is
cusparseZcsru2csr
cusparseZcsru2csr_bufferSizeExt
cusparseZgebsr2csr
This function converts a sparse matrix in BSR format that is defined by the three arrays bsrValA, bsrRowPtrA, and bsrColIndA) into a sparse matrix in CSR format that is defined by arrays csrValC, csrRowPtrC, and csrColIndC.
cusparseZgebsr2gebsc
This function can be seen as the same as csr2csc() when each block of size rowBlockDim*colBlockDim is regarded as a scalar.
cusparseZgebsr2gebsc_bufferSize
cusparseZgebsr2gebsc_bufferSizeExt
cusparseZgebsr2gebsr
This function converts a sparse matrix in general BSR format that is defined by the three arrays bsrValA, bsrRowPtrA, and bsrColIndA into a sparse matrix in another general BSR format that is defined by arrays bsrValC, bsrRowPtrC, and bsrColIndC.
cusparseZgebsr2gebsr_bufferSize
cusparseZgebsr2gebsr_bufferSizeExt
cusparseZgemvi
This function performs the matrix-vector operation
cusparseZgemvi_bufferSize
cusparseZgpsvInterleavedBatch
This function computes the solution of multiple penta-diagonal linear systems for i=0,…,batchCount:
cusparseZgpsvInterleavedBatch_bufferSizeExt
cusparseZgtsv2
This function computes the solution of a tridiagonal linear system with multiple right-hand sides:
cusparseZgtsv2StridedBatch
This function computes the solution of multiple tridiagonal linear systems for i=0,…,batchCount:
cusparseZgtsv2StridedBatch_bufferSizeExt
This function returns the size of the buffer used in gtsv2StridedBatch which computes the solution of multiple tridiagonal linear systems for i=0,…,batchCount:
cusparseZgtsv2_bufferSizeExt
cusparseZgtsv2_nopivot
This function computes the solution of a tridiagonal linear system with multiple right-hand sides:
cusparseZgtsv2_nopivot_bufferSizeExt
This function returns the size of the buffer used in gtsv2_nopivot which computes the solution of a tridiagonal linear system with multiple right-hand sides.
cusparseZgtsvInterleavedBatch
This function computes the solution of multiple tridiagonal linear systems for i=0,…,batchCount:
cusparseZgtsvInterleavedBatch_bufferSizeExt
cusparseZnnz
This function computes the number of nonzero elements per row or column and the total number of nonzero elements in a dense matrix.
cusparseZnnz_compress
This function is the step one to convert from csr format to compressed csr format.

Type Aliases

FILE
_IO_lock_t
__off64_t
__off_t
__uint64_t
bsric02Info_t
bsrilu02Info_t
bsrsm2Info_t
bsrsv2Info_t
csric02Info_t
csrilu02Info_t
csru2csrInfo_t
cuComplex
cuDoubleComplex
cuFloatComplex
cusparseColorInfo_tDeprecated
This is a pointer type to an opaque structure holding the information used in csrcolor().
cusparseConstDnMatDescr_t
cusparseConstDnVecDescr_t
cusparseConstSpMatDescr_t
cusparseConstSpVecDescr_t
cusparseDnMatDescr_t
cusparseDnVecDescr_t
cusparseHandle_t
This is a pointer type to an opaque cuSPARSE context, which the user must initialize by calling prior to calling cusparseCreate any other library function. The handle created and returned by cusparseCreate must be passed to every cuSPARSE function.
cusparseLoggerCallback_t
cusparseMatDescr_t
This structure is used to describe the shape and properties of a matrix.
cusparseSpGEMMDescr_t
cusparseSpMMOpPlan_t
cusparseSpMatDescr_t
cusparseSpSMDescr_t
cusparseSpSVDescr_t
cusparseSpVecDescr_t
pruneInfo_t
size_t