#[repr(u32)]pub enum cusparseDirection_t {
CUSPARSE_DIRECTION_ROW = 0,
CUSPARSE_DIRECTION_COLUMN = 1,
}Expand description
This type indicates whether the elements of a dense matrix should be parsed by rows or by columns (assuming column-major storage in memory of the dense matrix) in function cusparse[S|D|C|Z]nnz. Besides storage format of blocks in BSR format is also controlled by this type.
Variants
CUSPARSE_DIRECTION_ROW = 0
The matrix should be parsed by rows.
CUSPARSE_DIRECTION_COLUMN = 1
The matrix should be parsed by columns.