#[repr(u32)]pub enum cusparseFillMode_t {
CUSPARSE_FILL_MODE_LOWER = 0,
CUSPARSE_FILL_MODE_UPPER = 1,
}Expand description
This type indicates if the lower or upper part of a matrix is stored in sparse storage.
Variants
CUSPARSE_FILL_MODE_LOWER = 0
The lower triangular part is stored.
CUSPARSE_FILL_MODE_UPPER = 1
The upper triangular part is stored.