#[repr(u32)]pub enum cusparseFormat_t {
CUSPARSE_FORMAT_CSR = 1,
CUSPARSE_FORMAT_CSC = 2,
CUSPARSE_FORMAT_COO = 3,
CUSPARSE_FORMAT_BLOCKED_ELL = 5,
CUSPARSE_FORMAT_BSR = 6,
CUSPARSE_FORMAT_SLICED_ELLPACK = 7,
}Expand description
This type indicates the format of the sparse matrix. See cuSPARSE Storage Formats for their description.
Variants
CUSPARSE_FORMAT_CSR = 1
The matrix is stored in Compressed Sparse Row (CSR) format.
CUSPARSE_FORMAT_CSC = 2
The matrix is stored in Compressed Sparse Column (CSC) format.
CUSPARSE_FORMAT_COO = 3
The matrix is stored in Coordinate (COO) format organized in Structure of Arrays (SoA) layout.
CUSPARSE_FORMAT_BLOCKED_ELL = 5
The matrix is stored in Blocked-Ellpack (Blocked-ELL) format.
CUSPARSE_FORMAT_BSR = 6
The matrix is stored in Block Sparse Row (BSR) format.
CUSPARSE_FORMAT_SLICED_ELLPACK = 7