#[repr(u32)]pub enum cusparsePointerMode_t {
CUSPARSE_POINTER_MODE_HOST = 0,
CUSPARSE_POINTER_MODE_DEVICE = 1,
}Expand description
This type indicates whether the scalar values are passed by reference on the host or device. It is important to point out that if several scalar values are passed by reference in the function call, all of them will conform to the same single pointer mode. The pointer mode can be set and retrieved using cusparseSetPointerMode and cusparseGetPointerMode routines, respectively.
Variants
CUSPARSE_POINTER_MODE_HOST = 0
The scalars are passed by reference on the host.
CUSPARSE_POINTER_MODE_DEVICE = 1
The scalars are passed by reference on the device.