cusparseCcsrilu02_numericBoost

Function cusparseCcsrilu02_numericBoost 

pub unsafe extern "C" fn cusparseCcsrilu02_numericBoost(
    handle: cusparseHandle_t,
    info: csrilu02Info_t,
    enable_boost: c_int,
    tol: *mut f64,
    boost_val: *mut cuComplex,
) -> cusparseStatus_t
The user can use a boost value to replace a numerical value in incomplete LU factorization. The tol is used to determine a numerical zero, and the boost_val is used to replace a numerical zero. The behavior is

if tol >= fabs(A(j,j)), then A(j,j)=boost_val.

To enable a boost value, the user has to set parameter enable_boost to 1 before calling csrilu02(). To disable a boost value, the user can call csrilu02_numericBoost() again with parameter enable_boost=0.

If enable_boost=0, tol and boost_val are ignored.

Both tol and boost_val can be in the host memory or device memory. The user can set the proper mode with cusparseSetPointerMode.

  • The routine requires no extra storage.
  • The routine supports asynchronous execution.
  • The routine supports CUDA graph capture.