pub unsafe extern "C" fn cusparseCooSetPointers(
spMatDescr: cusparseSpMatDescr_t,
cooRows: *mut c_void,
cooColumns: *mut c_void,
cooValues: *mut c_void,
) -> cusparseStatus_tExpand description
This function sets the pointers of the sparse matrix descriptor spMatDescr.
cusparseCooSetPointers has the following constraints:
cooRows,cooColumns, andcooValuesmust be aligned to the size of their corresponding datatypes specified inspMatDescr. SeecudaDataType_tfor the description of the datatypes.
Parameters
spMatDescr: Sparse matrix descriptor.cooRows: Row indices of the sparse matrix. Array withnnzelements.cooColumns: Column indices of the sparse matrix. Array withnnzelements.cooValues: Values of the sparse matrix. Array withnnzelements.