cusparseCreateBsric02Info

Function cusparseCreateBsric02Info 

pub unsafe extern "C" fn cusparseCreateBsric02Info(
    info: *mut bsric02Info_t,
) -> cusparseStatus_t
๐Ÿ‘ŽDeprecated
This function creates and initializes the solve and analysis structure of block incomplete Cholesky to default values.

Parameters

  • info: the pointer to the solve and analysis structure of block incomplete Cholesky.