cusparseCreateBsrsm2Info

Function cusparseCreateBsrsm2Info 

pub unsafe extern "C" fn cusparseCreateBsrsm2Info(
    info: *mut bsrsm2Info_t,
) -> cusparseStatus_t
๐Ÿ‘ŽDeprecated
This function creates and initializes the solve and analysis structure of bsrsm2 to default values.

Parameters

  • info: the pointer to the solve and analysis structure of bsrsm2.