cusparseCreateCsric02Info

Function cusparseCreateCsric02Info 

pub unsafe extern "C" fn cusparseCreateCsric02Info(
    info: *mut csric02Info_t,
) -> cusparseStatus_t
๐Ÿ‘ŽDeprecated
This function creates and initializes the solve and analysis structure of incomplete Cholesky to default values.

Parameters

  • info: the pointer to the solve and analysis structure of incomplete Cholesky.