pub unsafe extern "C" fn cusparseCreateDnMat(
dnMatDescr: *mut cusparseDnMatDescr_t,
rows: i64,
cols: i64,
ld: i64,
values: *mut c_void,
valueType: cudaDataType,
order: cusparseOrder_t,
) -> cusparseStatus_tExpand description
The function initializes the dense matrix descriptor dnMatDescr.
cusparseCreateDnMat has the following constraints:
valuesmust be aligned to the size of the datatype specified byvalueType. SeecudaDataType_tfor the description of the datatypes.
Parameters
dnMatDescr: Dense matrix descriptor.rows: Number of rows of the dense matrix.cols: Number of columns of the dense matrix.ld: Leading dimension of the dense matrix.values: Values of the dense matrix. Array withsizeelements.valueType: Enumerator specifying the datatype ofvalues.order: Enumerator specifying the memory layout of the dense matrix.