cusparseCscSetPointers

Function cusparseCscSetPointers 

pub unsafe extern "C" fn cusparseCscSetPointers(
    spMatDescr: cusparseSpMatDescr_t,
    cscColOffsets: *mut c_void,
    cscRowInd: *mut c_void,
    cscValues: *mut c_void,
) -> cusparseStatus_t
This function sets the pointers of the sparse matrix descriptor spMatDescr.

cusparseCscSetPointers has the following constraints:

  • cscColOffsets, cscRowInd, and cscValues must be aligned to the size of their corresponding datatypes specified in spMatDescr. See cudaDataType_t for the description of the datatypes.

Parameters

  • spMatDescr: Sparse matrix descriptor.
  • cscColOffsets: Col offsets of the sparse matrix. Array with cols + 1 elements.
  • cscRowInd: Row indices of the sparse matrix. Array with nnz elements.
  • cscValues: Values of the sparse matrix. Array with nnz elements.