cusparseCsrSetPointers

Function cusparseCsrSetPointers 

pub unsafe extern "C" fn cusparseCsrSetPointers(
    spMatDescr: cusparseSpMatDescr_t,
    csrRowOffsets: *mut c_void,
    csrColInd: *mut c_void,
    csrValues: *mut c_void,
) -> cusparseStatus_t
This function sets the pointers of the sparse matrix descriptor spMatDescr.

cusparseCsrSetPointers has the following constraints:

  • csrRowOffsets, csrColInd, and csrValues must be aligned to the size of their corresponding datatypes specified in spMatDescr. See cudaDataType_t for the description of the datatypes.

Parameters

  • spMatDescr: Sparse matrix descriptor.
  • csrRowOffsets: Row offsets of the sparse matrix. Array with rows + 1 elements.
  • csrColInd: Column indices of the sparse matrix. Array with nnz elements.
  • csrValues: Values of the sparse matrix. Array with nnz elements.