pub unsafe extern "C" fn cusparseDestroyMatDescr(
descrA: cusparseMatDescr_t,
) -> cusparseStatus_tExpand description
This function releases the memory allocated for the matrix descriptor.
Parameters
descrA: the matrix descriptor.
pub unsafe extern "C" fn cusparseDestroyMatDescr(
descrA: cusparseMatDescr_t,
) -> cusparseStatus_tThis function releases the memory allocated for the matrix descriptor.
descrA: the matrix descriptor.