pub unsafe extern "C" fn cusparseDestroyPruneInfo(
info: pruneInfo_t,
) -> cusparseStatus_t๐Deprecated
This function destroys and releases any memory required by the structure.
Parameters
info: the structure ofprune.
pub unsafe extern "C" fn cusparseDestroyPruneInfo(
info: pruneInfo_t,
) -> cusparseStatus_tThis function destroys and releases any memory required by the structure.
info: the structure of prune.