pub unsafe extern "C" fn cusparseDgemvi(
handle: cusparseHandle_t,
transA: cusparseOperation_t,
m: c_int,
n: c_int,
alpha: *const f64,
A: *const f64,
lda: c_int,
nnz: c_int,
xVal: *const f64,
xInd: *const c_int,
beta: *const f64,
y: *mut f64,
idxBase: cusparseIndexBase_t,
pBuffer: *mut c_void,
) -> cusparseStatus_tExpand description
This function performs the matrix-vector operation
A is an $m \times n$ dense matrix and a sparse vector x that is defined in a sparse storage format by the two arrays xVal, xInd of length nnz, and y is a dense vector; $\alpha \;$ and $\beta \;$ are scalars; and

- The routine supports asynchronous execution
- The routine supports CUDA graph capture
The function cusparseDgemvi_bufferSize returns the size of buffer used in cusparseDgemvi.