cusparseDnMatGet

Function cusparseDnMatGet 

pub unsafe extern "C" fn cusparseDnMatGet(
    dnMatDescr: cusparseDnMatDescr_t,
    rows: *mut i64,
    cols: *mut i64,
    ld: *mut i64,
    values: *mut *mut c_void,
    type_: *mut cudaDataType,
    order: *mut cusparseOrder_t,
) -> cusparseStatus_t
This function returns the fields of the dense matrix descriptor dnMatDescr.

Parameters

  • dnMatDescr: Dense matrix descriptor.
  • rows: Number of rows of the dense matrix.
  • cols: Number of columns of the dense matrix.
  • ld: Leading dimension of the dense matrix.
  • values: Values of the dense matrix. Array with ld * cols elements.
  • order: Enumerator specifying the memory layout of the dense matrix.