cusparseDnMatSetValues

Function cusparseDnMatSetValues 

pub unsafe extern "C" fn cusparseDnMatSetValues(
    dnMatDescr: cusparseDnMatDescr_t,
    values: *mut c_void,
) -> cusparseStatus_t
This function sets the values field of the dense matrix descriptor dnMatDescr.

cusparseDnMatSetValues has the following constraints:

  • values must be aligned to the size of the datatype specified in dnMatDescr. See cudaDataType_t for the description of the datatypes.

Parameters

  • dnMatDescr: Dense matrix descriptor.
  • values: Values of the dense matrix. Array with ld * cols elements.