cusparseDnVecSetValues

Function cusparseDnVecSetValues 

pub unsafe extern "C" fn cusparseDnVecSetValues(
    dnVecDescr: cusparseDnVecDescr_t,
    values: *mut c_void,
) -> cusparseStatus_t
This function sets the values field of the dense vector descriptor dnVecDescr.

cusparseDnVecSetValues has the following constraints:

  • values must be aligned to the size of the datatype specified in dnVecDescr. Refer to cudaDataType_t for the description of the datatypes.

Parameters

  • dnVecDescr: Dense vector descriptor.
  • values: Values of the dense vector. Array with size elements.