cusparseDnnz

Function cusparseDnnz 

pub unsafe extern "C" fn cusparseDnnz(
    handle: cusparseHandle_t,
    dirA: cusparseDirection_t,
    m: c_int,
    n: c_int,
    descrA: cusparseMatDescr_t,
    A: *const f64,
    lda: c_int,
    nnzPerRowCol: *mut c_int,
    nnzTotalDevHostPtr: *mut c_int,
) -> cusparseStatus_t
This function computes the number of nonzero elements per row or column and the total number of nonzero elements in a dense matrix.

  • This function requires temporary extra storage that is allocated internally.
  • The routine supports asynchronous execution if the Stream Ordered Memory Allocator is available.
  • The routine supports CUDA graph capture if the Stream Ordered Memory Allocator is available.