pub unsafe extern "C" fn cusparseLoggerOpenFile(
logFile: *const c_char,
) -> cusparseStatus_tExpand description
Experimental: The function opens a logging output file in the given path.
Parameters
logFile: Path of the logging output file.
pub unsafe extern "C" fn cusparseLoggerOpenFile(
logFile: *const c_char,
) -> cusparseStatus_tExperimental: The function opens a logging output file in the given path.
logFile: Path of the logging output file.