pub unsafe extern "C" fn cusparseLoggerSetLevel(
level: c_int,
) -> cusparseStatus_tExpand description
Experimental: The function sets the value of the logging level. path.
Parameters
level: Value of the logging level.
pub unsafe extern "C" fn cusparseLoggerSetLevel(
level: c_int,
) -> cusparseStatus_tExperimental: The function sets the value of the logging level. path.
level: Value of the logging level.