pub unsafe extern "C" fn cusparseLoggerSetMask(
mask: c_int,
) -> cusparseStatus_tExpand description
Experimental: The function sets the value of the logging mask.
Parameters
mask: Value of the logging mask.
pub unsafe extern "C" fn cusparseLoggerSetMask(
mask: c_int,
) -> cusparseStatus_tExperimental: The function sets the value of the logging mask.
mask: Value of the logging mask.