pub unsafe extern "C" fn cusparseSbsric02_bufferSize(
handle: cusparseHandle_t,
dirA: cusparseDirection_t,
mb: c_int,
nnzb: c_int,
descrA: cusparseMatDescr_t,
bsrSortedVal: *mut f32,
bsrSortedRowPtr: *const c_int,
bsrSortedColInd: *const c_int,
blockDim: c_int,
info: bsric02Info_t,
pBufferSizeInBytes: *mut c_int,
) -> cusparseStatus_tExpand description
This function returns the size of a buffer used in computing the incomplete-Cholesky factorization with 0 fill-in and no pivoting
A is an (mb*blockDim)*(mb*blockDim) sparse matrix that is defined in BSR storage format by the three arrays bsrValA, bsrRowPtrA, and bsrColIndA.
The buffer size depends on the dimensions of mb, blockDim, and the number of nonzero blocks of the matrix nnzb. If the user changes the matrix, it is necessary to call bsric02_bufferSize() again to have the correct buffer size; otherwise, a segmentation fault may occur.
- The routine requires no extra storage.
- The routine supports asynchronous execution.
- The routine supports CUDA graph capture.