cusparseSbsrilu02_numericBoost

Function cusparseSbsrilu02_numericBoost 

pub unsafe extern "C" fn cusparseSbsrilu02_numericBoost(
    handle: cusparseHandle_t,
    info: bsrilu02Info_t,
    enable_boost: c_int,
    tol: *mut f64,
    boost_val: *mut f32,
) -> cusparseStatus_t
The user can use a boost value to replace a numerical value in incomplete LU factorization. Parameter tol is used to determine a numerical zero, and boost_val is used to replace a numerical zero. The behavior is as follows:

if tol >= fabs(A(j,j)), then reset each diagonal element of block A(j,j) by boost_val.

To enable a boost value, the user sets parameter enable_boost to 1 before calling bsrilu02(). To disable the boost value, the user can call bsrilu02_numericBoost() with parameter enable_boost=0.

If enable_boost=0, tol and boost_val are ignored.

Both tol and boost_val can be in host memory or device memory. The user can set the proper mode with cusparseSetPointerMode.

  • The routine requires no extra storage.
  • The routine supports asynchronous execution.
  • The routine supports CUDA graph capture.