cusparseScsrilu02_bufferSize

Function cusparseScsrilu02_bufferSize 

pub unsafe extern "C" fn cusparseScsrilu02_bufferSize(
    handle: cusparseHandle_t,
    m: c_int,
    nnz: c_int,
    descrA: cusparseMatDescr_t,
    csrSortedValA: *mut f32,
    csrSortedRowPtrA: *const c_int,
    csrSortedColIndA: *const c_int,
    info: csrilu02Info_t,
    pBufferSizeInBytes: *mut c_int,
) -> cusparseStatus_t
This function returns size of the buffer used in computing the incomplete-LU factorization with $0$ fill-in and no pivoting:

A is an $m \times m$ sparse matrix that is defined in CSR storage format by the three arrays csrValA, csrRowPtrA, and csrColIndA.

The buffer size depends on the dimension m and nnz, the number of nonzeros of the matrix. If the user changes the matrix, it is necessary to call csrilu02_bufferSize() again to have the correct buffer size; otherwise, a segmentation fault may occur.

  • The routine requires no extra storage.
  • The routine supports asynchronous execution.
  • The routine supports CUDA graph capture.