cusparseSgtsv2StridedBatch_bufferSizeExt

Function cusparseSgtsv2StridedBatch_bufferSizeExt 

pub unsafe extern "C" fn cusparseSgtsv2StridedBatch_bufferSizeExt(
    handle: cusparseHandle_t,
    m: c_int,
    dl: *const f32,
    d: *const f32,
    du: *const f32,
    x: *const f32,
    batchCount: c_int,
    batchStride: c_int,
    bufferSizeInBytes: *mut size_t,
) -> cusparseStatus_t
This function returns the size of the buffer used in gtsv2StridedBatch which computes the solution of multiple tridiagonal linear systems for i=0,…,batchCount:

The coefficient matrix A of each of these tri-diagonal linear system is defined with three vectors corresponding to its lower (dl), main (d), and upper (du) matrix diagonals; the right-hand sides are stored in the dense matrix X. Notice that solution Y overwrites right-hand-side matrix X on exit. The different matrices are assumed to be of the same size and are stored with a fixed batchStride in memory.

  • The routine requires no extra storage.
  • The routine supports asynchronous execution.
  • The routine supports CUDA graph capture.