cusparseSpGEMMreuse_nnz

Function cusparseSpGEMMreuse_nnz 

pub unsafe extern "C" fn cusparseSpGEMMreuse_nnz(
    handle: cusparseHandle_t,
    opA: cusparseOperation_t,
    opB: cusparseOperation_t,
    matA: cusparseConstSpMatDescr_t,
    matB: cusparseConstSpMatDescr_t,
    matC: cusparseSpMatDescr_t,
    alg: cusparseSpGEMMAlg_t,
    spgemmDescr: cusparseSpGEMMDescr_t,
    bufferSize2: *mut size_t,
    externalBuffer2: *mut c_void,
    bufferSize3: *mut size_t,
    externalBuffer3: *mut c_void,
    bufferSize4: *mut size_t,
    externalBuffer4: *mut c_void,
) -> cusparseStatus_t
This function computes the number of nonzero elements per row or column and the total number of nonzero elements in a dense matrix.

  • This function requires temporary extra storage that is allocated internally.
  • The routine supports asynchronous execution if the Stream Ordered Memory Allocator is available.
  • The routine supports CUDA graph capture if the Stream Ordered Memory Allocator is available.