pub unsafe extern "C" fn cusparseSpMatSetAttribute(
spMatDescr: cusparseSpMatDescr_t,
attribute: cusparseSpMatAttribute_t,
data: *mut c_void,
dataSize: size_t,
) -> cusparseStatus_tExpand description
The function sets the attributes of the sparse matrix descriptor spMatDescr
| Attribute | Meaning | Possible Values |
|---|---|---|
cusparseSpMatAttribute_t::CUSPARSE_SPMAT_FILL_MODE | Indicates if the lower or upper part of a matrix is stored in sparse storage | cusparseFillMode_t::CUSPARSE_FILL_MODE_LOWER, cusparseFillMode_t::CUSPARSE_FILL_MODE_UPPER |
cusparseSpMatAttribute_t::CUSPARSE_SPMAT_DIAG_TYPE | Indicates if the matrix diagonal entries are unity | cusparseDiagType_t::CUSPARSE_DIAG_TYPE_NON_UNIT, cusparseDiagType_t::CUSPARSE_DIAG_TYPE_UNIT |
Parameters
spMatDescr: Sparse matrix descriptor.attribute: Attribute enumerator.data: Attribute value.dataSize: Size of the attribute in bytes for safety.