cusparseSpMatSetValues

Function cusparseSpMatSetValues 

pub unsafe extern "C" fn cusparseSpMatSetValues(
    spMatDescr: cusparseSpMatDescr_t,
    values: *mut c_void,
) -> cusparseStatus_t
This function sets the values field of the sparse matrix descriptor spMatDescr.

cusparseSpMatSetValues has the following constraints:

  • values must be aligned to the size of its corresponding datatype specified in spMatDescr. See cudaDataType_t for the description of the datatypes.

Parameters

  • spMatDescr: Sparse matrix descriptor.
  • values: Values of the sparse matrix. Array with nnz elements.