pub unsafe extern "C" fn cusparseSpVecSetValues(
spVecDescr: cusparseSpVecDescr_t,
values: *mut c_void,
) -> cusparseStatus_tExpand description
This function sets the values field of the sparse vector descriptor spVecDescr.
cusparseDnVecSetValues has the following constraints:
valuesmust be aligned to the size of the datatype specified inspVecDescr. SeecudaDataType_tfor the description of the datatypes.
Parameters
spVecDescr: Sparse vector descriptor.values: Values of the sparse vector. Array withnnzelements.