pub unsafe extern "C" fn cusparseXcoo2csr(
handle: cusparseHandle_t,
cooRowInd: *const c_int,
nnz: c_int,
m: c_int,
csrSortedRowPtr: *mut c_int,
idxBase: cusparseIndexBase_t,
) -> cusparseStatus_tExpand description
This function converts the array containing the uncompressed row indices (corresponding to COO format) into an array of compressed row pointers (corresponding to CSR format).
It can also be used to convert the array containing the uncompressed column indices (corresponding to COO format) into an array of column pointers (corresponding to CSC format).
- The routine requires no extra storage.
- The routine supports asynchronous execution.
- The routine supports CUDA graph capture.