cusparseXcsr2coo

Function cusparseXcsr2coo 

pub unsafe extern "C" fn cusparseXcsr2coo(
    handle: cusparseHandle_t,
    csrSortedRowPtr: *const c_int,
    nnz: c_int,
    m: c_int,
    cooRowInd: *mut c_int,
    idxBase: cusparseIndexBase_t,
) -> cusparseStatus_t
This function converts the array containing the compressed row pointers (corresponding to CSR format) into an array of uncompressed row indices (corresponding to COO format).

It can also be used to convert the array containing the compressed column indices (corresponding to CSC format) into an array of uncompressed column indices (corresponding to COO format).

  • The routine requires no extra storage.
  • The routine supports asynchronous execution.
  • The routine supports CUDA graph capture.