pub unsafe extern "C" fn cusparseZgtsv2_nopivot_bufferSizeExt(
handle: cusparseHandle_t,
m: c_int,
n: c_int,
dl: *const cuDoubleComplex,
d: *const cuDoubleComplex,
du: *const cuDoubleComplex,
B: *const cuDoubleComplex,
ldb: c_int,
bufferSizeInBytes: *mut size_t,
) -> cusparseStatus_tExpand description
This function returns the size of the buffer used in gtsv2_nopivot which computes the solution of a tridiagonal linear system with multiple right-hand sides.
The coefficient matrix A of each of these tri-diagonal linear system is defined with three vectors corresponding to its lower (dl), main (d), and upper (du) matrix diagonals; the right-hand sides are stored in the dense matrix B. Notice that solution X overwrites right-hand-side matrix B on exit.
- The routine requires no extra storage.
- The routine supports asynchronous execution.
- The routine supports CUDA graph capture.