pub type cusparseMatDescr_t = *mut cusparseMatDescr;Expand description
This structure is used to describe the shape and properties of a matrix.
pub type cusparseMatDescr_t = *mut cusparseMatDescr;This structure is used to describe the shape and properties of a matrix.