#[repr(u32)]pub enum cusparseDiagType_t {
CUSPARSE_DIAG_TYPE_NON_UNIT = 0,
CUSPARSE_DIAG_TYPE_UNIT = 1,
}Expand description
This type indicates if the matrix diagonal entries are unity. The diagonal elements are always assumed to be present, but if cusparseDiagType_t::CUSPARSE_DIAG_TYPE_UNIT is passed to an API routine, then the routine assumes that all diagonal entries are unity and will not read or modify those entries. Note that in this case the routine assumes the diagonal entries are equal to one, regardless of what those entries are actually set to in memory.
Variants
CUSPARSE_DIAG_TYPE_NON_UNIT = 0
The matrix diagonal has non-unit elements.
CUSPARSE_DIAG_TYPE_UNIT = 1
The matrix diagonal has unit elements.