cusparseBsrSetStridedBatch

Function cusparseBsrSetStridedBatch 

pub unsafe extern "C" fn cusparseBsrSetStridedBatch(
    spMatDescr: cusparseSpMatDescr_t,
    batchCount: c_int,
    offsetsBatchStride: i64,
    columnsBatchStride: i64,
    ValuesBatchStride: i64,
) -> cusparseStatus_t
This function sets the batchCount and the batchStride fields of the sparse matrix descriptor spMatDescr.

Parameters

  • spMatDescr: Sparse matrix descriptor.
  • batchCount: Number of batches of the sparse matrix.
  • offsetsBatchStride: Address offset between consecutive batches for the row offset array.
  • columnsBatchStride: Address offset between consecutive batches for the column array.