pub unsafe extern "C" fn cusparseCgemvi(
handle: cusparseHandle_t,
transA: cusparseOperation_t,
m: c_int,
n: c_int,
alpha: *const cuComplex,
A: *const cuComplex,
lda: c_int,
nnz: c_int,
xVal: *const cuComplex,
xInd: *const c_int,
beta: *const cuComplex,
y: *mut cuComplex,
idxBase: cusparseIndexBase_t,
pBuffer: *mut c_void,
) -> cusparseStatus_tExpand description
This function performs the matrix-vector operation
A is an $m \times n$ dense matrix and a sparse vector x that is defined in a sparse storage format by the two arrays xVal, xInd of length nnz, and y is a dense vector; $\alpha \;$ and $\beta \;$ are scalars; and

- The routine supports asynchronous execution
- The routine supports CUDA graph capture
The function cusparseCgemvi_bufferSize returns the size of buffer used in cusparseCgemvi.