cusparseCooSetPointers

Function cusparseCooSetPointers 

pub unsafe extern "C" fn cusparseCooSetPointers(
    spMatDescr: cusparseSpMatDescr_t,
    cooRows: *mut c_void,
    cooColumns: *mut c_void,
    cooValues: *mut c_void,
) -> cusparseStatus_t
This function sets the pointers of the sparse matrix descriptor spMatDescr.

cusparseCooSetPointers has the following constraints:

  • cooRows, cooColumns, and cooValues must be aligned to the size of their corresponding datatypes specified in spMatDescr. See cudaDataType_t for the description of the datatypes.

Parameters

  • spMatDescr: Sparse matrix descriptor.
  • cooRows: Row indices of the sparse matrix. Array with nnz elements.
  • cooColumns: Column indices of the sparse matrix. Array with nnz elements.
  • cooValues: Values of the sparse matrix. Array with nnz elements.