pub unsafe extern "C" fn cusparseCreate(
handle: *mut cusparseHandle_t,
) -> cusparseStatus_tExpand description
This function initializes the cuSPARSE library and creates a handle on the cuSPARSE context. It must be called before any other cuSPARSE API function is invoked. It allocates hardware resources necessary for accessing the GPU.
Parameters
handle: The pointer to the handle to the cuSPARSE context.