pub unsafe extern "C" fn cusparseCreateBsric02Info(
info: *mut bsric02Info_t,
) -> cusparseStatus_t๐Deprecated
This function creates and initializes the solve and analysis structure of block incomplete Cholesky to default values.
Parameters
info: the pointer to the solve and analysis structure of block incomplete Cholesky.