pub unsafe extern "C" fn cusparseCreateBsrsv2Info(
info: *mut bsrsv2Info_t,
) -> cusparseStatus_t๐Deprecated
This function creates and initializes the solve and analysis structure of bsrsv2 to default values.
Parameters
info: the pointer to the solve and analysis structure of bsrsv2.