pub unsafe extern "C" fn cusparseCreateCsrilu02Info(
info: *mut csrilu02Info_t,
) -> cusparseStatus_t๐Deprecated
This function creates and initializes the solve and analysis structure of incomplete LU to default values.
Parameters
info: the pointer to the solve and analysis structure of incomplete LU.