cusparseCreateDnMat

Function cusparseCreateDnMat 

pub unsafe extern "C" fn cusparseCreateDnMat(
    dnMatDescr: *mut cusparseDnMatDescr_t,
    rows: i64,
    cols: i64,
    ld: i64,
    values: *mut c_void,
    valueType: cudaDataType,
    order: cusparseOrder_t,
) -> cusparseStatus_t
The function initializes the dense matrix descriptor dnMatDescr.

cusparseCreateDnMat has the following constraints:

  • values must be aligned to the size of the datatype specified by valueType. See cudaDataType_t for the description of the datatypes.

Parameters

  • dnMatDescr: Dense matrix descriptor.
  • rows: Number of rows of the dense matrix.
  • cols: Number of columns of the dense matrix.
  • ld: Leading dimension of the dense matrix.
  • values: Values of the dense matrix. Array with size elements.
  • valueType: Enumerator specifying the datatype of values.
  • order: Enumerator specifying the memory layout of the dense matrix.