pub unsafe extern "C" fn cusparseCreateIdentityPermutation(
handle: cusparseHandle_t,
n: c_int,
p: *mut c_int,
) -> cusparseStatus_t👎Deprecated
This function creates an identity map. The output parameter p represents such map by p = 0:1:(n-1).
This function is typically used with coosort, csrsort, cscsort.
- The routine requires no extra storage.
- The routine supports asynchronous execution.
- The routine supports CUDA graph capture.