pub unsafe extern "C" fn cusparseCsrSetPointers(
spMatDescr: cusparseSpMatDescr_t,
csrRowOffsets: *mut c_void,
csrColInd: *mut c_void,
csrValues: *mut c_void,
) -> cusparseStatus_tExpand description
This function sets the pointers of the sparse matrix descriptor spMatDescr.
cusparseCsrSetPointers has the following constraints:
csrRowOffsets,csrColInd, andcsrValuesmust be aligned to the size of their corresponding datatypes specified inspMatDescr. See cudaDataType_t for the description of the datatypes.
Parameters
spMatDescr: Sparse matrix descriptor.csrRowOffsets: Row offsets of the sparse matrix. Array withrows + 1elements.csrColInd: Column indices of the sparse matrix. Array withnnzelements.csrValues: Values of the sparse matrix. Array withnnzelements.