pub unsafe extern "C" fn cusparseDnMatGetStridedBatch(
dnMatDescr: cusparseConstDnMatDescr_t,
batchCount: *mut c_int,
batchStride: *mut i64,
) -> cusparseStatus_tExpand description
The function returns the number of batches and the batch stride of the dense matrix descriptor dnMatDescr.
Parameters
dnMatDescr: Dense matrix descriptor.batchCount: Number of batches of the dense matrix.batchStride: Address offset between a matrix and the next one in the batch.