pub unsafe extern "C" fn cusparseDnMatSetStridedBatch(
dnMatDescr: cusparseDnMatDescr_t,
batchCount: c_int,
batchStride: i64,
) -> cusparseStatus_tExpand description
The function sets the number of batches and the batch stride of the dense matrix descriptor dnMatDescr.
Parameters
dnMatDescr: Dense matrix descriptor.batchCount: Number of batches of the dense matrix.batchStride: Address offset between a matrix and the next one in the batch.batchStride ≥ ld * colsif the matrix uses column-major layout,batchStride ≥ ld * rowsotherwise.