pub unsafe extern "C" fn cusparseDnMatSetValues(
dnMatDescr: cusparseDnMatDescr_t,
values: *mut c_void,
) -> cusparseStatus_tExpand description
This function sets the values field of the dense matrix descriptor dnMatDescr.
cusparseDnMatSetValues has the following constraints:
valuesmust be aligned to the size of the datatype specified indnMatDescr. SeecudaDataType_tfor the description of the datatypes.
Parameters
dnMatDescr: Dense matrix descriptor.values: Values of the dense matrix. Array withld * colselements.