pub unsafe extern "C" fn cusparseDnVecSetValues(
dnVecDescr: cusparseDnVecDescr_t,
values: *mut c_void,
) -> cusparseStatus_tExpand description
This function sets the values field of the dense vector descriptor dnVecDescr.
cusparseDnVecSetValues has the following constraints:
valuesmust be aligned to the size of the datatype specified indnVecDescr. Refer tocudaDataType_tfor the description of the datatypes.
Parameters
dnVecDescr: Dense vector descriptor.values: Values of the dense vector. Array withsizeelements.