pub unsafe extern "C" fn cusparseGetStream(
handle: cusparseHandle_t,
streamId: *mut cudaStream_t,
) -> cusparseStatus_tExpand description
This function gets the cuSPARSE library stream, which is being used to to execute all calls to the cuSPARSE library functions. If the cuSPARSE library stream is not set, all kernels use the default NULL stream.
Parameters
handle: The handle to the cuSPARSE context.streamId: The stream used by the library.