cusparseLoggerSetFile

Function cusparseLoggerSetFile 

pub unsafe extern "C" fn cusparseLoggerSetFile(
    file: *mut FILE,
) -> cusparseStatus_t
Experimental: The function sets the logging output file. Note: once registered using this function call, the provided file handle must not be closed unless the function is called again to switch to a different file handle.

Parameters

  • file: Pointer to an open file. File should have write permission.