cusparseScatter

Function cusparseScatter 

pub unsafe extern "C" fn cusparseScatter(
    handle: cusparseHandle_t,
    vecX: cusparseConstSpVecDescr_t,
    vecY: cusparseDnVecDescr_t,
) -> cusparseStatus_t
The function scatters the elements of the sparse vector vecX into the dense vector vecY

In other words,

for i=0 to nnz-1
Y[X_indices[i]] = X_values[i]

cusparseScatter supports the following index type for representing the sparse vector vecX:

cusparseScatter supports the following data types:

cusparseScatter has the following constraints:

  • The arrays representing the sparse vector vecX must be aligned to 16 bytes

cusparseScatter has the following properties:

  • The routine requires no extra storage
  • The routine supports asynchronous execution
  • Provides deterministic (bit-wise) results for each run if the the sparse vector vecX indices are distinct
  • The routine allows indices of vecX to be unsorted

cusparseScatter supports the following optimizations:

  • CUDA graph capture
  • Hardware Memory Compression

Please visit cuSPARSE Library Samples - cusparseScatter for a code example.

Parameters

  • handle: Handle to the cuSPARSE library context.
  • vecX: Sparse vector X.
  • vecY: Dense vector Y.