pub unsafe extern "C" fn cusparseSetPointerMode(
handle: cusparseHandle_t,
mode: cusparsePointerMode_t,
) -> cusparseStatus_tExpand description
This function sets the pointer mode used by the cuSPARSE library. The default is for the values to be passed by reference on the host. Please see the section on the cublasPointerMode_t type for more details.
Parameters
handle: The handle to the cuSPARSE context.mode: One of the enumerated pointer mode types.