pub unsafe extern "C" fn cusparseSpGEAM_nnz(
handle: cusparseHandle_t,
opA: cusparseOperation_t,
opB: cusparseOperation_t,
alpha: *const c_void,
matA: cusparseSpMatDescr_t,
beta: *const c_void,
matB: cusparseSpMatDescr_t,
matC: cusparseSpMatDescr_t,
computeType: cudaDataType,
alg: cusparseSpGEAMAlg_t,
spgeamDescr: cusparseSpGEAMDescr_t,
externalBuffer: *mut c_void,
) -> cusparseStatus_tExpand description
This function computes the number of nonzero elements per row or column and the total number of nonzero elements in a dense matrix.
- This function requires temporary extra storage that is allocated internally.
- The routine supports asynchronous execution if the Stream Ordered Memory Allocator is available.
- The routine supports CUDA graph capture if the Stream Ordered Memory Allocator is available.