pub unsafe extern "C" fn cusparseSpMatSetValues(
spMatDescr: cusparseSpMatDescr_t,
values: *mut c_void,
) -> cusparseStatus_tExpand description
This function sets the values field of the sparse matrix descriptor spMatDescr.
cusparseSpMatSetValues has the following constraints:
valuesmust be aligned to the size of its corresponding datatype specified inspMatDescr. SeecudaDataType_tfor the description of the datatypes.
Parameters
spMatDescr: Sparse matrix descriptor.values: Values of the sparse matrix. Array withnnzelements.