cusparseSpVecSetValues

Function cusparseSpVecSetValues 

pub unsafe extern "C" fn cusparseSpVecSetValues(
    spVecDescr: cusparseSpVecDescr_t,
    values: *mut c_void,
) -> cusparseStatus_t
This function set the values field of the sparse vector descriptor spVecDescr.

cusparseDnVecSetValues has the following constraints:

  • values must be aligned to the size of the datatype specified in spVecDescr. See cudaDataType_t for the description of the datatypes.

Parameters

  • spVecDescr: Sparse vector descriptor.
  • values: Values of the sparse vector. Array with nnz elements.