pub unsafe extern "C" fn cusparseSparseToDense(
handle: cusparseHandle_t,
matA: cusparseConstSpMatDescr_t,
matB: cusparseDnMatDescr_t,
alg: cusparseSparseToDenseAlg_t,
externalBuffer: *mut c_void,
) -> cusparseStatus_tExpand description
The function converts the sparse matrix matA in CSR, CSC, or COO format into its dense representation matB. Blocked-ELL is not currently supported.
The function cusparseSparseToDense_bufferSize returns the size of the workspace needed by cusparseSparseToDense.
cusparseSparseToDense supports the following index type for representing the sparse matrix matA:
- 32-bit indices (
cusparseIndexType_t::CUSPARSE_INDEX_32I) - 64-bit indices (
cusparseIndexType_t::CUSPARSE_INDEX_64I)
cusparseSparseToDense supports the following data types:
cusparseSparse2Dense() supports the following algorithm:
| Algorithm | Notes |
|---|---|
cusparseSparseToDenseAlg_t::CUSPARSE_SPARSETODENSE_ALG_DEFAULT | Default algorithm |
cusparseSparseToDense has the following properties:
- The routine requires no extra storage
- The routine supports asynchronous execution
- Provides deterministic (bit-wise) results for each run
- The routine allows the indices of
matAto be unsorted
cusparseSparseToDense supports the following optimizations:
- CUDA graph capture
- Hardware Memory Compression
Please visit cuSPARSE Library Samples - cusparseSparseToDense for a code example.
Parameters
handle: Handle to the cuSPARSE library context.matA: Sparse matrixA.matB: Dense matrixB.alg: Algorithm for the computation.