pub unsafe extern "C" fn cusparseXcsric02_zeroPivot(
handle: cusparseHandle_t,
info: csric02Info_t,
position: *mut c_int,
) -> cusparseStatus_t๐Deprecated
If the returned error code is cusparseStatus_t::CUSPARSE_STATUS_ZERO_PIVOT, position=j means A(j,j) has either a structural zero or a numerical zero; otherwise, position=-1.
The position can be 0-based or 1-based, the same as the matrix.
Function cusparseXcsric02_zeroPivot is a blocking call. It calls cudaDeviceSynchronize() to make sure all previous kernels are done.
The position can be in the host memory or device memory. The user can set proper mode with cusparseSetPointerMode.
- The routine requires no extra storage.
- The routine supports asynchronous execution if the Stream Ordered Memory Allocator is available.
- The routine supports CUDA graph capture if the Stream Ordered Memory Allocator is available.
Parameters
position: if no structural or numerical zero,positionis -1; otherwise, ifA(j,j)is missing orL(j,j)is zero,position=j.