pub type cusparseHandle_t = *mut cusparseContext;Expand description
This is a pointer type to an opaque cuSPARSE context, which the user must initialize by calling prior to calling cusparseCreate any other library function. The handle created and returned by cusparseCreate must be passed to every cuSPARSE function.